                        GEODESIC PROGRAM MANUAL

;note: this manual is available from within the program itself under HELP.

                              CONTENTS
                     (use drop-downs to select)

     INTRODUCTION... data on geodesics, program theory, and author's notes

     GETTING STARTED... system requirements, set-up, and program limits

     SCREEN DISPLAY... detailed information on screen displayed spheres

     DROP-DOWN MENUS... using the selections
       for printing instructions, see FILE, sub catagory Print

     TOOLBOX... tools and using them

     CREATING SPHERES... general guide and using your created geodesics

<INTRO                       INTRODUCTION

>                             Geodesics

     Geodesic refers to the shortest distance between two points on a 
sphere (forming a chord), and is always on a great circle (the circle 
created when a sphere is cut in two exact halves).  The concept of 
creating a sphere using multiple flat faces was expanded by Buckminister 
Fuller with formulae to convert spherical triangles to flat triangles, as 
well as other work which aids in creating domes.

     Unfortunately, the amount of math required to create a geodesic 
structure is incredibly difficult and tedious.  This program is designed 
to remove the difficulty in generating various spheres and domes.  
Hopefully, now anybody can create a geodesic structure with no prior 
mathematical or spherical knowledge.

     Geodesic dome houses are practical for several reasons.

--  First, the inside volume of a sphere is the largest with regard to the 
surface area.  This means that the material required to create the shell 
is the smallest possible for the inside space.

-- Second, the dome is self supporting.  No internal construction is 
necessary to provide roof support.

-- Third, the shape of the dome is aero-dynamic.  With its smooth round 
surface, it is less prone to high wind attacks.

-- Fourth, it is physically more stable than a standard house.  The bulk 
of the dome is low and there are no large flat walls which can fold flat 
like a box.  It should withstand earthquakes much better.

     Large domes should not be used in heavy snow conditions since the top 
of the dome is relatively flat and will allow heavy snow build-up.

>                       Dome House Construction

     Since domes are constructed using many faces, special consideration 
needs to be used when sealing the cracks between faces.  I believe this to 
be less troublesome if new techniques are implemented.  Three methods come 
to mind;

1. Melt strips of roofing material such as BRAI (plastic tar) over each 
crack.

2. Use fiberglass strips or cloth soaked with fiberglass resin over each 
crack.

3. Use Silicone Rubber in each crack.

     Large domes with many small faces are weaker than domes made with 
fewer large faces.  This is due to the smaller angles between each face, 
and can be illustrated by bending a flat piece of paper versus a partially 
folded piece of paper.  The angle of the fold adds strength.  Also, when 
constructing a dome, the full strength is only realized when the dome is 
completed, and all faces are securely fastened together.  Several large 
domes have collapsed during construction before the final top sections 
could be installed.  This is generally a problem on domes 100 feet or more 
in diameter.  Still, support may be necessary on smaller domes during 
construction.

     Usually, the dome should be constructed loosely until all of the 
faces are in place, then tightened firmly together.  This is necessary 
since small errors in face sizes add up as faces are added around the 
dome.  For instance, if you have a 1/10" error on each face and 50 faces
are needed around the base, by the time you arrive at the starting point, 
you could have a 5" gap or overlap to join up to the first face.

     This program calculates face construction details.  Several 
selections for wood sizes are available.  Framing is generated using 
perpendicular cuts to the face surface, which means that a miter saw is 
all that is necessary to cut the frame and studs... no extremely difficult 
multiple angle cuts.  The frames are inset from the outside face edges so 
they will meet on the inside surface of the dome.  This leaves a gap 
between the outside frames which needs to be filled, and dihedral boards 
are generated to fill this need.  A table saw or radial arm saw is 
necessary for the strips of dihedral boards outside of the frame, which 
need to be cut at an angle.  These boards provide the pressure strength to 
support the dome.  The alternative to this method of construction is too 
ugly with multiple compound angle cuts required.

     Each frame board is provided with bolt hole positions to match 
adjacent faces.

     This program also provides outside face dimensions as well as inside 
face dimensions which are adjusted slightly in size to account for 
material thickness and dihedral angles (angles between faces).

>                          Program Theory

     The basic concept of this program is to generate spheres and domes 
using one of eighteen spherical solids as a starting basis. (All points 
reside on the sphere surface.)  The spherical solid is then broken into 
smaller triangular faces, and finally cut to provide a flat base.  Some of 
the possibilities are not really practical for creating houses due to the 
many different face shapes generated, although the this program's method 
for face construction considerably simplifies otherwise difficult wood 
cutting.

     The program maintains two arrays for working with the sphere... a 
points array and a faces array.  The points array stores the cartesian 
coordinates (x,y,z) of each point.  The faces array stores the points used 
for each face and face attributes.  Both these arrays are dynamically 
altered in size as additional storage becomes necessary.  Rotations are 
performed on the points array only.  A change in sphere radius is 
performed by converting the points to spherical coordinates (vectors... 
two angles and a length), then altering the length of the vector, and re-
converting back to cartesian coordinates.

     Breakdowns into smaller faces are performed using only two algorithms 
(methods for performing a task), and all breakdowns are performed with 
various combinations of the two.

1.   The first method is a triacon breakdown which can be used on any face 
shape.  Triacon breakdowns are performed by finding the center of each 
face and creating a new point above that location on the sphere surface.  
All of the old face edges go away and new face edges are created between 
the center points and existing old face points.  Effectively, this yields 
a 1.7 frequency breakdown, and none of the old face edges remain.  (A 
second application of the triacon breakdown restores the old edges with a 
3 frequency breakdown product.)

2.   The second method is a 2 frequency breakdown which can be used only 
on triangular faces.  A new point is created at the center of each face 
edge, and new faces are added between the points.  Effectively, one 
triangle is divided into four triangles.

     Spearpoint raising creates a new point above the center of the face 
on the sphere surface, then creates new triangles connecting each of the 
face points.

     Displaying the sphere on the screen is performed by drawing faces 
from the back of the sphere to the front so that front faces will will not 
be hidden by back faces.  This was accomplished by calculating the formula 
for each face plane, then sorting according to the depth of intersection 
between the plane and the axis line pointing toward you.

     3D display for those of you with Stereo-Tek glasses requires that 
each eye sees an image from a different angle.  Two complete pictures are 
drawn 5 degrees rotation apart.  The two pictures are alternately 
displayed, each eye of the viewer seeing one of the two pictures while the 
other eye is 'shuttered' off.  The effect is a true three dimensional 
image.  The optimum distance from the screen for viewing is about 2 feet.  
Moving farther away tends to stretch the sphere into an egg shape.  Moving 
closer to the screen flattens the sphere.

>                         Practical Spheres

     Typically, spheres made using solids of few points (Tetrahedron, 
Hexahedron) breakdown into faces which have negative dihedral angles 
(faces which point outward from the sphere and join with other faces in a 
crevice, or indented joint).  These faces have one long edge and two short 
edges usually.  Although this program works properly with these faces, 
house construction becomes a bit more complex.

     The most commonly used solids for sphere construction are the 
Octahedron (8 faces) and the Icosahedron (20 faces).  Generally, these 
shapes breakdown into fewer face shapes since they begin with equalateral 
triangles only.  The Octahedron has a flat base at the half-sphere point.  
The Icosahedron is usually cut at the 3/8 or 5/8 level.  Not only are 
there fewer face shapes for these spheres, but also the calculations are 
considerably easier (for those who don't use this program).


>                           Author's Note

     I began this program with calculation routines to convert between 
flat and spherical triangles (CALC drop-down menu).  It soon became 
obvious that the difficulty still existed for dome creation.  A simpler 
method was required.  Thus the concept of using existing spherical solids 
as a basis and breaking them down into smaller faces was born.  

     No mathematical knowledge is required by the user... this program 
provides complex routines for performing the necessary calculations. (I 
spent considerable time pouring through calculus books and writing 
routines to solve simultaneous equations, spherical geometry calculations, 
and other necessary mathematical functions.)  The result is an easy to use 
program which manipulates spherical faces and generates lists with 
graphical data for the actual construction of a real geodesic structure.

     I sincerely hope that you enjoy using this program, and possibly get 
some real benefit from it.  If you have any suggestions for improvement or 
added functions, please let me know.

     My GEnie BBS address is R.MCKAIG

     Ray S. McKaig
     555 Riverview Drive
     Boulder Creek, CA 95006
     (408) 338-3693
     

<START                     GETTING STARTED

>                        System Requirements

     You must have a monochrome monitor since this program only runs in 
high resolution.  Also, a hard disk is highly recommended due to the 
storage size requirements.  Although this program will run on a one 
megabyte machine (spheres are limited by memory available), additional 
memory is very desirable... four megabytes removes any limitations on the 
program, or number of faces to be manipulated.

>                         Program Limitations

     A maximum of 32760 faces is allowed (Far too many from a practical 
point of view).

     There is no practical limit to the sphere radius.

     This program only creates the shell.  The interior of the house is 
left up to the imagination of you.

     Methodology for sphere breakdown in one case is not as efficient as 
it could be.  The case is equilateral triangles broken into 3 frequency 
divisions.  (frequency is the number of sections each edge of a face is 
divided into.)  It is possible to end up with 2 different triangle shapes 
only after breakdown, however this program generates three different 
shapes.  The advantage is that the resulting triangles are more uniformly 
similar in size, yielding a more uniformly spherical sphere.

     During breakdown, it is important that all faces have adjacent faces 
touching within the area of where you intend to cut the sphere into a 
dome.  If not, the breakdown algorithm will create additional triangles on 
the edges having no adjacent faces. (A three frequency breakdown ends up 
with 4 divisions instead of 3 on the edges.) To prevent this from 
happening, it is best to start with a full sphere before breakdown.

     The CAMERA tool is memory intensive.  It uses most all of the 
remaining memory to generate the many picture angles, and the size of the 
display sphere generated is reduced according to the number of pictures 
desired and memory available.  Please note that saving the movie requires 
a hard disk due to the size of the file.

>                             Beginning

     If your disk has a file called GEODESIC.LZH, you will need to 
decompress the file.  This must be done with Quester's LZH decompression 
program available on BBS systems such as GEnie.

HARD DISK:
     You should create a folder and place all of the files in it.  Then 
you are ready to start.  Execute the GEODESIC.PRG file.

FLOPPY DISK:
     Although floppy disks are not recommended due to size limitations, 
they can be used.  This GEODESIC program is self-contained (except for the 
manual if you intend to access it while in the program).
     Insert your floppy (a copy, preferably) and execute GEODESIC.PRG.  
Once this program is executed, you may use a blank floppy disk or one with 
a manual on it for online help.

     You can play with the program immediately, but reading the section on 
TOOLS will most helpful.  The next section you should be familiar with are 
the Drop-Down MENUS.  I have always believed that experience is the best 
teacher, so working (or playing) with the program will give you the 
experience needed and expertise for most operations.

     Since this manual is on-line under the HELP drop-down menu, it may be 
consulted at any time if you find yourself perplexed.

<SCREEN                    SCREEN DISPLAY

>                           Screen Format

     Upon executing the program, a title picture is displayed while the 
program initializes and generates the TOOL box display.  Once all is 
initialized, the title picture is rolled up from the bottom of the screen 
and the main work screen is displayed.

     The screen has several areas of importance.

1.  Across the top line are the drop-down menus, with an area on the top 
right which gives a short explanation of the TOOL the mouse pointer is 
over, or if the mouse is to the left of the TOOL box the current tool 
selection is displayed.

2.  On the extreme left, status information about the current sphere is 
displayed when available.

3.  In the center of the screen is the sphere work area, depicted by a 
circle with cross hairs.

4.  Below the circle is the name of the spherical solid currently selected 
upon which the sphere is based on.

5.  Below the circle to the right is the sphere orientation AXIS 
indicator.  It can be changed for X, Y, or Z axis display.

6.  Next to the AXIS indicator is a graphical picture of the basic sphere 
solid with the edge length shown above.  The edge length displays the 
length of all the lines intersecting two faces, which changes with a 
radius change.  This is provided for information only.

7.  Above and to the right of the sphere is an area used for status while 
the program is busy working.

8.  The TOOL box is displayed on the right of the screen which houses the 
working tools and convenience tools.

<MENUS                     DROP-DOWN MENUS

>                              Hot Keys

     Many of the drop-down menu items provide 'HOT KEY' access for fast 
selection without using the mouse.  On the right of the selection may be a 
hot key designation tor access.

-->  '^' indicates the Control key must be pressed prior to the character.

-->  A 'black box character' indicates that the Alternate key must be 
pressed prior to the character.

-->  'Fn' where n is a number indicates the function key corresponding 
which is found across the top of the keyboard.


>                                DESK

     The program version number can be found in the drop-down item 'About 
GEODESIC'.

     Loaded desk accessories may be accessed here.

>                                FILE

     This has the disk operations LOAD, SAVE, DELETE for spheres, the disk
MOVIE operations for loading and saving, the disk operation DEGAS for 
generating DEGAS compatible pictures, and PRINT functions.

--> Load Sphere:  A previously saved sphere is retrieved from disk

--> Save Sphere:  The current sphere in the work circle is saved to disk

--> Delete Sphere:  Allows deleting files on disks.  The file type
    defaults to ".GEO", however any file may be deleted.  You are prompted
    (if the file exists) to insure that you wish to delete the file.

--> Load Movie:  A previously saved Movie created with the Camera tool is
    loaded.  Note: If your memory available is smaller than when you
    created the movie, some of the frames will be removed causing jumps in
    the rotation during display.  To avoid this, clear your working sphere
    first.  
      This can be done by saving the sphere to disk if desired, then
    selecting a new sphere from the drop-down menu SPHERES.

--> Save Movie: You can save a movie to disk which you have generated
    using the Camera tool.  The file is stored in a compressed format on
    disk.

--> Save Degas: This will create a picture of your sphere into a name.PI3
    file which can then be painted using the Degas paint program.  You can
    specify the percentage of size you wish for the picture.
    (The program's title picture was created using this function with
    various spheres generated.)

--> Print: This is a general entry into the various print functions.  You
    may print to the screen, or if you have GDOS installed (from booting)
    you can print to a graphic printer.  A 300 dot-per-inch printer is
    recommended for construction print-outs.  GDOS requires that the
    ASSIGN.SYS file has an appropriate printer driver for your printer.

   Picture:      You can print a picture of your sphere of varying sizes
                 and display modes.
   Construction: You can print detailed diagrams for constructing the
                 sphere faces.  First, a listing of sphere details, common
                 faces and face numbers to reference them by.
                 Next, graphic printout of face details and orientation
                 dots for each unique face shape is done.
                 Finally, graphic printout of the sphere with face
                 locations and orienting dots is provided.

          Faces only: Prints the outside surface faces and dimensions
                      only, suitable for paper construction.
          Faces and Frames: Prints full construction details for house
                      construction.  You are first prompted for details on
                      material sizes and number display preference.

     Note: You may abort printout by pressing the ESC key.  (The computer
           may take a while to finish the current procedure before an
           abort request is tested)  You are then prompted to insure you
           really wish to abort.
           When printing to the screen, you may continue to the next
           screen by pressing any key (except ESC), or the left mouse
           button. (ESC or the right mouse button will request an abort.)

--> Quit exits the program.  If you have not saved your sphere since it 
    was modified, you are prompted to do so.  Also, if you have used the 
    CAMERA tool and a 'Movie' is in memory, you are asked if you wish to
    save the movie.  (This requires a fair amount of disk space.)

>                               SPHERES
     Selection of the 18 basic spherical solids for new sphere creations 
is found here, as well as the desired radius for the sphere.

     Selecting one of the spheres will clear the workspace and set up the 
program for a new basic sphere solid creation.  If your current sphere has 
not been saved, you will first be prompted to do so.  To generate the new 
sphere, use the ADD tool in FACE mode (see TOOLS).

--> RADIUS  The sphere radius can be changed at any time. Click on this 
selection and type in the new value.  Your sphere data will be updated for 
the new size.

>                               ROTATE

     Rotation degrees can be set here for the rotation tool (circle with 
arrows).
     Several selections for rotation increments are available, the most 
important have function keys (hot keys) for quick changing.

     The selections are:
     .1 Degree
      1 Degree
      5 Degrees  (F5)
     10 Degrees  (F10)
     15 Degrees  (F1)
     30 Degrees  (F3)
     45 Degrees  (F4)
     60 Degrees  (F6)
     72 Degrees  (F7)
     90 Degrees  (F9)


--> Add Face Rotate

     This is only useful when adding faces to a basic sphere solid, and 
works with the ADD function in single FACE mode (not AREA mode... these 
are selected in the tool box).       

     When a new face is joined to another face, the sphere is rotated so 
the face added is in the front center of the work area.  This makes adding 
multiple faces easier since the sphere need not be manually rotated to a 
new position to expose an area free for the next face to add.


--> SET HOME

     When this function is selected, the current orientation of the sphere 
is remembered.  At some future time when you have rotated the sphere to a 
different orientation,  you can click on the HOME tool (located in the 
center of the rotate tool) and have your sphere returned to its home 
position.

>                               DISPLAY

     Provides visual display selections.  You can reverse the screen, 
select how you wish to display the sphere, and if you have 3-D glasses 
connected to the expansion port, you can see the sphere stand out from the 
screen in its 3-dimensional glory.

--> TOGGLE BACKGROUND: Reverses the screen colors

--> Show AXIS Toward You: These selections allow the sphere to be viewed 
    from the three different axis.  Default is X.

    X, Y, or Z axis selections are available.
    Clicking one of these selections re-displays the sphere in a new 
    orientation with the selected axis pointing out of the screen toward
    you, and changes the AXIS indicator below and to the right of the
    sphere.

--> All Faces: These selections change the sphere display to show all of 
    the sphere faces (as opposed to Front Faces Only).  This is useful
    with solid or shaded faces for displaying spheres with windows or
    missing sections to see the rear faces, and is also useful with
    wire-frame mode (All Edges) to see all edges.

--> All Edges: Draws all face edges only, no filled faces.  This is wire-
    frame mode, and is probably more useful with 3D glasses since the rear
    faces appear behind the screen and the front faces stand out toward
    you.

--> Solid Out, Dotted In: Front faces are solid white, while rear faces 
    are pattern filled using the 24 system fill patterns (less black).

--> Dotted Out, Solid In: Just the reverse of the above.

--> Shaded Faces: 37 shading patterns are used by depth.  Front faces are
    white or lightly shaded while the rear faces become darker... the most
    rear becoming black.

--> Front Faces Only: Only the faces on the front of the sphere are drawn.  
    This is much faster than drawing all of the faces.  This is also less 
    confusing when working with the sphere since only the faces you can
    work on are displayed.

        The display selections are the same for All Faces (above).  Clear 
    Front Faces is wire frame mode... the faces are not filled.

--> 3D Stereo-tek Glasses: This is only available if you have the module 
    which came with your glasses plugged into the expansion port of your 
    computer.  This activates or deactivates the 3D display capability.

>                                CALC

     Provides the tedious conversions between spherical and flat triangles 
for those of you who wish to slug it out the old way of creating Geodesic 
structures.  This is provided as a convenience only for mathematicians 
working the spherical equations and face breakdowns.

--> Spherical from Flat Triangles: Allows entry of flat triangle parameters
    and calculates the corresponding spherical triangle using the current
    sphere radius.

--> Flat from Spherical Triangles: Allows entry of spherical triangle 
    parameters using the current sphere radius and calculates the 
    corresponding flat triangle.

>                                HELP

--> Manual: Online display of this manual

--> Operation: A short description for using this program.

--> Geodesics: general information on Geodesics

<TOOLS                      TOOLBOX TOOLS

>                             Sections

     The Bottom of the TOOL box has the six basic shapes for creating the 
basic 18 spherical solids.  These are used when first generating a sphere 
with the ADD tool in FACE mode.
     Only the appropriate selections are available for the current sphere 
selected under the SPHERES drop-down menu, as indicated by a white 
background.

     Above the basic shapes is section of face work tools.  These consist 
of a mode switch (FACE, AREA) which selects between single face operations 
or faces within a draw area.  The tools in this section are Spearpoint 
raising, Window toggling, ADD faces, and DELete faces.

     The next section above has the major modification tools... Frequency 
Breakdown, and Cut Sphere.

     Above the major modification tools are the display tools.  These 
consist of sphere rotation tools (circle with arrows), a convenience 
toggle tool called DISP which switches between display modes, and a toggle 
tool to switch between a reference circle with cross-hairs or not.

     The next section up has the Movie tools which allow the generation 
and display of multiple views of the sphere.

>                       Using FACE or AREA mode

--> FACE mode allows single face operations on the four tools in the tool 
    box section (SPEARPOINT, WINDOW, ADD, DEL).

       Pointing the mouse at the face desired in the sphere working circle
    and left-clicking activates the function for the tool selected.
    (Exception: See ADD, FACE mode)

--> AREA mode affects the four tools in the tool box section (SPEARPOINT, 
    WINDOW, ADD, DEL).  To use, one of the four tools must be selected,
    and AREA must be selected.  Move the mouse into the sphere working
    circle.
       Left click the mouse to begin.  You can now draw a flashing line
    around the faces or area you wish to affect.  Left clicking again will
    close the circle and begin the operation selected, else right clicking
    will abort.

>                             SPEARPOINT

     This tool raises points in the middle of selected faces and creates 
new triangles.  Each face selected is effectively broken into smaller 
triangles connected to all points of the face.  (See 'Using FACE or AREA 
mode' for selecting faces)

>                               WINDOW

     This tool toggles selected faces between 'windows' you can see 
through, and solid faces.  (See 'Using FACE or AREA mode' for selecting 
faces)

>                           ADD, FACE mode

     When first creating a basic sphere solid, this tool activates the 
appropriate basic shapes for the currently selected sphere at the bottom 
of the tool box.

     These shapes can be selected by clicking on the shape desired (the 
shapes not highlighted are available).  By moving the mouse into the work 
screen to the left, the shape appears.  When the shape is moved into the 
sphere circle, the shape moves on the surface of the sphere.  Left click 
to place the face on the sphere.  You can place the first face anywhere, 
but all succeeding faces must be joined to existing faces at two points.  
(A picture of the basic sphere solid is provided at the bottom left of the 
tool box for face location reference.)

     In order to position the faces to be added, the right mouse button 
held down allows rotation of the face.  By moving the mouse forward or 
backward with the right button down, the face will rotate.  Release the 
button when the face is close to where you want it.  Exact positioning is 
not required.  As long as the connecting points are within 1/3 edge 
length, the program will know which points you wish to join.  Left click 
to add the face.

>                           ADD, AREA mode

--> Used after the sphere has undergone a breakdown to smaller faces.

       Use this tool when you have deleted faces you wish to restore, or
    just fill an area with faces.  The computer will attempt to figure out
    the best configuration for faces to add in the selected area.  Draw
    your area around at least 3 points.  (See 'Using FACE or AREA mode'
    for drawing the working area)

>                                DEL

     This tool deletes selected faces from the sphere.  (See 'Using FACE 
or AREA mode' for selecting faces)

     If you delete faces you want back, use the ADD tool in AREA mode.


>                             BREAKDOWN

     This tool initiates a breakdown of the working sphere into smaller 
faces.  You can select between several breakdowns.  Additional breakdowns 
may be performed later to further reduce the face sizes.

     The frequency of the breakdown indicates how many sections each edge 
is divided into.  (4 frequency divides each edge into 4 lengths)

     By observing the edge lengths status data displayed on the left of 
the screen, you can determine just how far you want to break the sphere 
down to meet material requirements for the construction of your dome.  
Adjustments to the radius (SPHERES drop-down menu) will increase or 
decrease the edge lengths.

     Triacon breakdowns change the edges.  Two triacon breakdowns in a row 
restore the original edges, with a three frequency breakdown result.

     To use this tool, left-click on the BREAKDOWN tool and select your 
choice from the selections box which appears.

>                              CUT SPHERE

     This tool will shear your sphere into a dome with a flat base.  
Further cuts can be performed later to further reduce the dome height.  In 
order to cut a sphere, three points need to be selected around the sphere 
to define a flat plane for the base.

     To use this tool, first left-click on the CUT SPHERE tool.  Then move 
the mouse into the working area to the left.  You will be prompted to 
select the first point, and a line will appear on the sphere.  Move the 
mouse close to your selected point... the line should move to that level 
and the point you want should have a circle around it.  (Right click to 
abort)  When you have the point where you want it, left-click the mouse.  
The sphere is then rotated 120 degrees (1/3 rotation) and you are prompted 
for the second point.  (the first point will be visible for reference)  
Again, select the point desired as done above, and the sphere is again 
rotated 120 degrees for the third point.  This time, the line becomes an 
ellipse defining a plane.  As you move the mouse to different points, the 
new plane is calculated and the ellipse follows the cut line.  Again, 
left-click on your point.  Now the sphere is rotated for the flat base and 
redrawn.  You are prompted "Cut Here?" and must answer with Y to perform 
the cut.
     A selection box appears for the determination of which way you wish 
to cut the sphere.

--> CUT will shear the faces along the base, increasing the number of face
    points.

--> MOVE will move points below the base up to the base, modifying the
    face shape.  This yields different face shapes.  Note: this is only
    performed if all base faces are triangles, else the CUT is performed.

--> MOVE NEAR POINTS  will move any close points to the base if possible
    which makes for fewer small faces and larger base faces.

--> TRY FOR CIRCLE will attempt to move base points which have been cut to
    the circle formed where the base plane cuts the sphere.
       Trapezoids (4 point faces) will have their bottom lines extended
    the the circle.
     A word of caution: This may form tall narrow triangles in the base.

     If your sphere has not been saved prior to this function, a SAVE 
operation is performed first before the cut.  Enter the name you want to 
save the sphere under.  (You need not enter the .GEO... the program will 
do this for you.)

>                                DISP

     This tool is a convenience for creating basic sphere solids.  It 
toggles between Clear Front Faces and All Solid Out, Dotted In.

     Sometimes you cannot see where to add a new face when building your 
sphere.  This switches the display mode to show rear faces.

     You could build your sphere with all faces showing, but it takes 
longer to draw the sphere.  Clear Front Faces is relatively fast.

>                               CIRCLE

     The displayed reference circle with cross-hairs can be toggled on or 
off with this tool.

>                              ROTATION

     These tools are the arrows.  They allow rotation of the sphere in 10 
different directions.  The amount of rotation is determined by the current 
selection under the ROTATE drop-down menu.

     Left-clicking in an arrow will perform a sphere rotation in the 
desired direction.

     Right-clicking on an arrow will continuously rotate the sphere until 
another mouse click is done.

>                               HOME

     This tool resides in the center of the rotate tools, and will rotate 
the sphere to the home position (previously set with the 'Set Home' 
selection under the ROTATE drop-down menu).

>                              CAMERA

     This tool will create a series of pictures of your sphere, each 
picture from a different rotated view.  When finished, the MOVIE tool is 
used to display the pictures.

     When this tool is left-clicked on, you are prompted for the number of 
pictures you want for a full 360 degree display.  The more the pictures, 
the smoother the MOVIE display, but the longer it will take to generate 
and potentially the smaller each picture will be depending on available 
memory.  Also, you can select which mode to display your picture, and 
rotation direction.

     If you have 3D Stereo-Tek glasses, 72 pictures are required and the 
rotation must be left-right.

     Since the CAMERA function uses a tremendous amount of memory, further 
sphere work is not possible without first unloading the memory.  This is 
accomplished by re-entering the Camera tool, allow the tool to clear 
memory, then abort the generation of a new new movie.

>                               MOVIE

     This tool is available when the Camera tool has been used, or a movie 
has been loaded from disk.  Activate it by left-clicking on the tool.

     It provides a fast rotating display of your sphere in two modes which 
are toggled with the left mouse button.  Right-click to exit.

Mode 1. Left-right motion of the mouse rotates the display in proportion
      to the position of the mouse.

Mode 2. The sphere continually rotates in the direction the mouse is
      moved.  The speed of rotation is controlled by the distance you move
      the mouse.  

<CREATE                   CREATING NEW SPHERES

>                            Basic Solids

     The general idea of this program is to first create the basic 
spherical solids you wish to use and saving them to disk.  Once created, 
they can be used repeatedly to generate complex spheres and domes.

     Basic spherical solids are made by selecting the type of solid from 
the SPHERES dropdown menu, then using the ADD tool (in FACE mode) to place 
the face shapes in place.  This is the 'puzzle' aspect of the program.
Complete solids can only be be made when the faces are placed in their 
correct positions.  As an aid, only the correct face types are available 
to be selected, and a graphic picture of a complete sphere is shown for 
reference.

     Once the basic solid is complete, it should be rotated to the 
orientation of your preference, then saved to disk under a descriptive 
name.  (example: An ICOSOHEDRON is generated, then saved as "ICOSAHED.GEO"
to the disk.)  You may also wish to set the radius of the sphere prior to 
saving it.

>                       Modifying a Basic Solid

     To generate a geodesic structure, load (if not already in memory) the 
basic spherical solid you wish to work with.  Then using the various tools 
in the TOOLS box and drop-down menu items, proceed to modify the basic 
spherical solid by break-downs, cut the base (if desired), toggle window 
faces to see through, and save the new geodesic to disk under a different 
name than the basic spherical solid (or else you will lose your basic solid 
and will need to regenerate it).

>                         Using your Geodesic

     Several things can be done with your geodesic sphere.

1.   Select the display mode desired, select the rotation increments, and
use the rotate tools to view from different angles.

2.   Select the CAMERA tool, and generate a 'movie' for fast rotation 
display.  Then click on the MOVIE tool and move the mouse.

3.   Save the geodesic to disk using the DEGAS function under the FILE 
drop-down menu.  The created picture can then be loaded into the DEGAS or 
DEGAS-ELITE paint program for picture painting.

4.   Print the geodesic to your graphical printer.

--- You can print a picture only of your geodesic.
--- You can print detailed construction information for creating a model
    or a shell for a house. (I have not actually constructed one yet.  If 
    one of you people actually uses this program for construction, please 
    let me know the results.  The program (in theory) should create 
    useable information for construction.
       Construction information is in two forms:
          Faces only... suitable for paper constructions. No thickness
                        information is used, so the actual face outside
                        dimensions only are generated.
          Full Detailed Construction... uses wood thickness and sizes to 
                        modify output dimensions.  Framing, outside and 
                        inside face dimensions (adjusted for thickness and
                        angles) are generated.  The method of framing
                        uses right angle techniques for easy construction.

